@@ -5,6 +5,7 @@ import Himari.CharSpec qualified as CharSpec
 import Himari.Env.SimpleSpec qualified as SimpleSpec
 import Himari.Prelude.FunctorSpec qualified as FunctorSpec
 import HlintBaseSpec qualified
+import HlintExtensionSpec qualified
 import HlintUnliftioSpec qualified
 import Test.Syd
 import TitleSpec qualified
@@ -17,3 +18,4 @@ main = sydTest $ do
   describe "Prelude.Functor" FunctorSpec.spec
   describe "HlintUnliftio" HlintUnliftioSpec.spec
   describe "HlintBase" HlintBaseSpec.spec
+  describe "HlintExtension" HlintExtensionSpec.spec
